@@ -2,10 +2,10 @@ from typing import List
 
 import click
 
+from sym.cli.decorators import loses_interactivity
 from sym.cli.helpers.check.runner import must_run_all
+from sym.cli.helpers.global_options import GlobalOptions
 
-from ..decorators import loses_interactivity
-from ..helpers.global_options import GlobalOptions
 from .sym import sym
 
 
