@@ -14,17 +14,25 @@ from .sym import sym
 @resource_argument
 @click.option("--instance", help="Instance ID to connect to", required=True)
 @click.option("--port", default=22, type=int, show_default=True)
+@click.option("--skip-ensure-key", default=False, envvar="SYM_SKIP_ENSURE_KEY")
 @click.make_pass_decorator(GlobalOptions)
 @skip_analytics
 @require_login
 @loses_interactivity
-def ssh_session(options: GlobalOptions, resource: str, instance: str, port: int):
+def ssh_session(
+    options: GlobalOptions,
+    resource: str,
+    instance: str,
+    port: int,
+    skip_ensure_key: bool,
+):
     target_options = TargetOptions(host=instance, port=port)
     request_data = RequestData(
         action="ssh_session",
         resource=resource,
         global_options=options,
         target_options=target_options,
+        params={"ensure_key": not skip_ensure_key},
     )
 
     ActionRegistry.execute(request_data)
