@@ -18,7 +18,7 @@ class CachingEc2Client(MultiRegionEc2Client):
         an entry in "aliases" that matches.
         """
         for instance_id, server in Config.get_servers().items():
-            if (region := server.get("region")) :
+            if region := server.get("region"):
                 if alias == instance_id:
                     return RunningInstance(instance_id=alias, region=region)
 
@@ -43,7 +43,7 @@ class CachingEc2Client(MultiRegionEc2Client):
         Otherwise, the instance is loaded by delegating to a MultiRegionEc2Client,
         then stored in the config before returning.
         """
-        if (existing := self._load_from_config(alias)) :
+        if existing := self._load_from_config(alias):
             return existing
 
         instance = super().load_instance_by_alias(alias)
