@@ -1,6 +1,7 @@
 import shlex
 import subprocess
 from configparser import ConfigParser, NoOptionError
+from functools import cached_property
 from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
 
@@ -26,7 +27,9 @@ from ..helpers.params import Profile, get_saml2aws_params
 from .saml_client import SAMLClient
 
 MIN_VERSION = VersionInfo.parse("2.26.2")
-PREFERRED_VERSION = VersionInfo.parse("2.28.3")
+MIN_DOUBLE_OKTA_VERSION = VersionInfo.parse("2.28.3")
+MIN_CACHE_VERSION = VersionInfo.parse("2.29.0")
+PREFERRED_VERSION = VersionInfo.parse("2.30.0")
 
 ErrorPatterns = {
     Saml2AwsNoRoles: UnavailableResourceError,
@@ -58,10 +61,10 @@ class Saml2Aws(SAMLClient):
             "config": str(self.config_file),
             "idp_account": self._section_name,
             "skip_prompt": True,
-            "cache_saml": True,
         }
 
-    def _check_version(self) -> bool:
+    @cached_property
+    def _version(self) -> VersionInfo:
         # Can't use run_subprocess because saml2aws annoyingly outputs the version on stderr
         version = subprocess.run(
             ["saml2aws", "--version"],
@@ -69,17 +72,32 @@ class Saml2Aws(SAMLClient):
             capture_output=True,
         ).stderr
         if not version:
+            return VersionInfo.parse("0.0.0")
+
+        return VersionInfo.parse(version.strip())
+
+    def _check_version(self) -> bool:
+        if self._version < MIN_VERSION:
             return False
 
-        parsed = VersionInfo.parse(version.strip())
-        if parsed < MIN_VERSION:
-            return False
-        if parsed < PREFERRED_VERSION:
+        if self._version < MIN_DOUBLE_OKTA_VERSION:
             click.secho(
                 f"Hint: Your version of saml2aws has a bug that will cause double Okta prompts. Try upgrading to at least {PREFERRED_VERSION}.\n",
                 err=True,
                 fg="cyan",
             )
+        elif self._version < MIN_CACHE_VERSION:
+            click.secho(
+                f"Hint: Your version of saml2aws has a bug related to caching. Try upgrading to at least {PREFERRED_VERSION}.\n",
+                err=True,
+                fg="cyan",
+            )
+        elif self._version < PREFERRED_VERSION:
+            click.secho(
+                f"Hint: Your version of saml2aws is out of date. Try upgrading to at least {PREFERRED_VERSION}.\n",
+                err=True,
+                fg="cyan",
+            )
         return True
 
     def is_setup(self) -> bool:
@@ -132,8 +150,13 @@ class Saml2Aws(SAMLClient):
             options = {**self._s2a_options}
             args = {}
 
-        if force or self.options.disable_caches or not self.has_creds():
-            options["cache_saml"] = False
+        if (
+            self._version >= MIN_CACHE_VERSION
+            and not force
+            and not self.options.disable_caches
+            and self.has_creds()
+        ):
+            args["cache_saml"] = True
 
         with push_envs(self._saml2aws_envs()):
             # no-op if session active when force=False
