@@ -1,10 +1,10 @@
 from multiprocessing import Pool
 
 import pytest
-from expects import *
+from expects import expect, have_key
+from sym.shared.cli.tests.helpers.capture import CaptureCommand
 
 from sym.cli.saml_clients.aws_okta import AwsOkta
-from sym.cli.tests.helpers.capture import CaptureCommand
 from sym.cli.tests.saml_clients.conftest import TestContextFixture
 
 pytestmark = [
